@@ -23,7 +23,7 @@ class LiveStreamer(_Streamer):
         super().__init__(source, rate)
         self._stream = cv2.VideoCapture(self.source)
         self._fps = self._stream.get(cv2.CAP_PROP_FPS)
-        self._need_to_wait = - 1. / rate
+        self._need_to_wait = 1. / rate
         self._last_time = - 1. / rate
         self._error_frames = 0
         self._max_errors = max_errors
