@@ -4,12 +4,9 @@ package utilities module
 """
 
 import shutil
-from lockfile import LockFile
 from pathlib import Path
 from ffmpy import FFmpeg
 
-from sail_utils import LOGGER
-
 
 def _merge(start_epoch: int,
            end_epoch: int,
